@@ -13,7 +13,7 @@ from devolv.drift.aws_fetcher import (
 )
 from devolv.drift.issues import create_approval_issue, wait_for_sync_choice
 from devolv.drift.github_approvals import create_github_pr
-from devolv.drift.report import print_drift_diff
+from devolv.drift.report import print_drift_diff, normalize_statement
 
 app = typer.Typer()
 
@@ -24,12 +24,7 @@ def push_branch(branch_name: str):
         subprocess.run(["git", "config", "user.name", "github-actions"], check=True)
         subprocess.run(["git", "add", "."], check=True)
         subprocess.run(["git", "commit", "-m", f"Update policy: {branch_name}"], check=True)
-        try:
-            subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
-        except subprocess.CalledProcessError:
-            typer.echo("⚠️ Initial push failed. Attempting rebase + push...")
-            subprocess.run(["git", "pull", "--rebase", "origin", branch_name], check=True)
-            subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
+        subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
         typer.echo(f"✅ Pushed branch {branch_name} to origin.")
     except subprocess.CalledProcessError as e:
         typer.echo(f"❌ Git command failed: {e}")
@@ -43,8 +38,17 @@ def close_issue(repo_full_name, token, issue_num, comment):
     issue.edit(state="closed")
 
 def detect_drift(local_doc, aws_doc) -> bool:
-    local_statements = {json.dumps(s, sort_keys=True) for s in local_doc.get("Statement", [])}
-    aws_statements = {json.dumps(s, sort_keys=True) for s in aws_doc.get("Statement", [])}
+    """
+    Detect removal drift: AWS has permissions missing from local.
+    """
+    local_statements = {
+        json.dumps(normalize_statement(s), sort_keys=True)
+        for s in local_doc.get("Statement", [])
+    }
+    aws_statements = {
+        json.dumps(normalize_statement(s), sort_keys=True)
+        for s in aws_doc.get("Statement", [])
+    }
     missing_in_local = aws_statements - local_statements
     if missing_in_local:
         typer.echo("❌ Drift detected: Local is missing permissions present in AWS.")
@@ -54,12 +58,12 @@ def detect_drift(local_doc, aws_doc) -> bool:
 
 @app.command()
 def drift(
-    policy_name: str = typer.Option(..., "--policy-name", help="Name of the IAM policy"),
-    policy_file: str = typer.Option(..., "--file", help="Path to local policy file"),
-    account_id: str = typer.Option(None, "--account-id", help="AWS Account ID (optional)"),
+    policy_name: str = typer.Option(..., "--policy-name"),
+    policy_file: str = typer.Option(..., "--file"),
+    account_id: str = typer.Option(None, "--account-id"),
     approvers: str = typer.Option("", help="Comma-separated GitHub usernames for approval"),
-    approval_anyway: bool = typer.Option(False, "--approval-anyway", help="Request approval even if no drift"),
-    repo_full_name: str = typer.Option(None, "--repo", help="GitHub repo full name (org/repo)")
+    approval_anyway: bool = typer.Option(False, "--approval-anyway"),
+    repo_full_name: str = typer.Option(None, "--repo")
 ):
     iam = boto3.client("iam")
     if not account_id:
@@ -93,48 +97,35 @@ def drift(
     repo_full_name = repo_full_name or os.getenv("GITHUB_REPOSITORY")
     token = os.getenv("GITHUB_TOKEN")
     if not repo_full_name:
-        typer.echo("❌ GitHub repo not specified. Use --repo or set GITHUB_REPOSITORY.")
+        typer.echo("❌ GitHub repo not specified.")
         raise typer.Exit(1)
     if not token:
-        typer.echo("❌ GITHUB_TOKEN not set in environment.")
+        typer.echo("❌ GITHUB_TOKEN not set.")
         raise typer.Exit(1)
 
     assignees = [a.strip() for a in approvers.split(",") if a.strip()]
     issue_num, _ = create_approval_issue(repo_full_name, token, policy_name, assignees=assignees)
-    issue_url = f"https://github.com/{repo_full_name}/issues/{issue_num}"
-    typer.echo(f"✅ Approval issue created: {issue_url}")
+    typer.echo(f"✅ Approval issue created: https://github.com/{repo_full_name}/issues/{issue_num}")
 
     choice = wait_for_sync_choice(repo_full_name, issue_num, token)
 
     if choice == "local->aws":
         merged_doc = merge_policy_documents(local_doc, aws_doc)
-        try:
-            _update_aws_policy(iam, policy_arn, merged_doc)
-        except ValueError as ve:
-            typer.echo(str(ve))
-            raise typer.Exit(1)
-        typer.echo(f"✅ AWS policy {policy_arn} updated with local changes (append-only).")
-        close_issue(repo_full_name, token, issue_num, "✅ AWS updated with local changes. Closing issue.")
-
+        _apply_aws_update_and_close(iam, policy_arn, merged_doc, repo_full_name, token, issue_num, "✅ AWS updated with local changes.")
     elif choice == "aws->local":
         _update_local_and_create_pr(aws_doc, policy_file, repo_full_name, policy_name, issue_num, token, "from AWS policy")
-        close_issue(repo_full_name, token, issue_num, "✅ Local policy updated from AWS. Closing issue.")
-
     elif choice == "aws<->local":
         superset_doc = build_superset_policy(local_doc, aws_doc)
-        try:
-            _update_aws_policy(iam, policy_arn, superset_doc)
-        except ValueError as ve:
-            typer.echo(str(ve))
-            raise typer.Exit(1)
-        typer.echo(f"✅ AWS policy {policy_arn} updated with superset of local + AWS.")
+        _apply_aws_update_and_close(iam, policy_arn, superset_doc, repo_full_name, token, issue_num, "✅ Superset applied.")
         _update_local_and_create_pr(superset_doc, policy_file, repo_full_name, policy_name, issue_num, token, "with superset of local + AWS")
-        close_issue(repo_full_name, token, issue_num, "✅ Superset applied. Closing issue.")
-
     else:
         typer.echo("⏭ No synchronization performed (skip).")
         close_issue(repo_full_name, token, issue_num, "⏭ No sync chosen. Closing issue.")
 
+def _apply_aws_update_and_close(iam, policy_arn, doc, repo, token, issue_num, message):
+    _update_aws_policy(iam, policy_arn, doc)
+    close_issue(repo, token, issue_num, message)
+
 def _update_aws_policy(iam, policy_arn, policy_doc):
     sids = [stmt.get("Sid") for stmt in policy_doc.get("Statement", []) if "Sid" in stmt]
     if len(sids) != len(set(sids)):
@@ -156,24 +147,11 @@ def _update_aws_policy(iam, policy_arn, policy_doc):
     print(f"✅ AWS policy {policy_arn} updated successfully.")
 
 def _update_local_and_create_pr(doc, policy_file, repo_full_name, policy_name, issue_num, token, description=""):
-    new_content = json.dumps(doc, indent=2)
     with open(policy_file, "w") as f:
-        f.write(new_content)
-    timestamp = datetime.utcnow().strftime("%Y%m%d-%H%M%S")
-    branch = (
-        f"drift-sync-{policy_name}-{timestamp}"
-        .replace(' ', '-')
-        .replace('+', 'plus')
-        .replace('/', '-')
-        .strip('-')
-        .lower()
-    )
+        f.write(json.dumps(doc, indent=2))
+    branch = f"drift-sync-{policy_name}-{datetime.utcnow().strftime('%Y%m%d-%H%M%S')}".replace(' ', '-').replace('+', 'plus').replace('/', '-').strip('-').lower()
     push_branch(branch)
     pr_title = f"Update {policy_file} {description}"
     pr_body = f"This PR updates `{policy_file}` {description}.\n\nLinked to issue #{issue_num}."
     pr_num, pr_url = create_github_pr(repo_full_name, branch, pr_title, pr_body, issue_num=issue_num)
-    gh = Github(token)
-    repo = gh.get_repo(repo_full_name)
-    issue = repo.get_issue(number=issue_num)
-    issue.create_comment(f"✅ PR created and linked: {pr_url}. Closing issue.")
-    issue.edit(state="closed")
+    close_issue(repo_full_name, token, issue_num, f"✅ PR created and linked: {pr_url}. Closing issue.")
