@@ -2,7 +2,6 @@ import json
 import difflib
 from rich.console import Console
 from rich.text import Text
-import typer
 
 def clean_policy(policy):
     """
@@ -33,45 +32,20 @@ def normalize_statement(stmt):
         stmt["Resource"] = normalize_resource(stmt["Resource"])
     return stmt
 
-def detect_drift(local_doc, aws_doc) -> bool:
+def normalize_policy(policy):
     """
-    Detect removal drift: AWS has permissions missing from local (danger).
+    Clean and normalize an entire policy.
     """
-    local_statements = {
-        json.dumps(normalize_statement(s), sort_keys=True)
-        for s in local_doc.get("Statement", [])
-    }
-    aws_statements = {
-        json.dumps(normalize_statement(s), sort_keys=True)
-        for s in aws_doc.get("Statement", [])
-    }
-
-    missing_in_local = aws_statements - local_statements
-
-    if missing_in_local:
-        typer.echo("❌ Drift detected: Local is missing permissions present in AWS.")
-        return True
-
-    typer.echo("✅ No removal drift detected (local may have extra permissions; that's fine).")
-    return False
+    cleaned = clean_policy(policy)
+    cleaned["Statement"] = [normalize_statement(s) for s in cleaned.get("Statement", [])]
+    return cleaned
 
 def generate_diff_lines(local_doc: dict, aws_doc: dict):
     """
     Generate a unified diff between local and AWS policy JSONs.
     """
-    local_clean = clean_policy(local_doc)
-    aws_clean = clean_policy(aws_doc)
-
-    # Normalize resources before dumping for diff
-    local_clean["Statement"] = [
-        normalize_statement(s) for s in local_clean.get("Statement", [])
-    ]
-    aws_clean["Statement"] = [
-        normalize_statement(s) for s in aws_clean.get("Statement", [])
-    ]
-
-    local_str = json.dumps(local_clean, indent=2, sort_keys=True)
-    aws_str = json.dumps(aws_clean, indent=2, sort_keys=True)
+    local_str = json.dumps(normalize_policy(local_doc), indent=2, sort_keys=True)
+    aws_str = json.dumps(normalize_policy(aws_doc), indent=2, sort_keys=True)
 
     return list(difflib.unified_diff(
         local_str.splitlines(),
